OkfExecutor class final

Instructions for running an Attested Computation.

Properties

hashCode int
The hash code for this object.
no setterinherited
raw Map<String, Object?>
The full mapping, including producer extensions.
final
receipt List<String>
Fields a computation run must return.
no setter
resource String?
Path or URI naming the run instructions or code.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(Object? value) OkfExecutor?
Attempts to read an executor mapping.