OkfFindingLocation class final

A reported source position associated with a bundle.

Constructors

OkfFindingLocation({required String path, int? line, int? column})
Creates a source location.
factory

Properties

column int?
The one-based source column, when known.
final
hashCode int
The hash code for this object.
no setteroverride
line int?
The one-based source line, when known.
final
path String
The reported source path, which may identify a malformed bundle entry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Projects this location as a JSON-compatible object.
toString() String
Renders path, path:line, or path:line:column.
override

Operators

operator ==(Object other) bool
The equality operator.
override