OkfGraphEdgeOrigin enum

Where a graph relationship was discovered.

Inheritance
Available extensions

Values

const OkfGraphEdgeOrigin('body')
resource → const OkfGraphEdgeOrigin
const OkfGraphEdgeOrigin('resource')
sourceResource → const OkfGraphEdgeOrigin
const OkfGraphEdgeOrigin('sources.resource')
computation → const OkfGraphEdgeOrigin
const OkfGraphEdgeOrigin('computation')
executorResource → const OkfGraphEdgeOrigin
const OkfGraphEdgeOrigin('executor.resource')
attesterResource → const OkfGraphEdgeOrigin
const OkfGraphEdgeOrigin('attester.resource')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String
Stable JSON and diagram label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OkfGraphEdgeOrigin>
A constant List of the values in this enum, in order of their declaration.