OkfLegacyCitation class final

One entry from a legacy v0.1 # Citations section.

Constructors

OkfLegacyCitation({required int number, required String title, required String target, required String raw})
Creates a parsed legacy citation.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
number int
Explicit citation number, or its one-based order in an unnumbered list.
final
raw String
Original citation line, without surrounding whitespace.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
Markdown link destination.
final
title String
Markdown link label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override