OkfSpecValidator class final

Checks the pinned OKF v0.2 requirements with a fixed internal rule set.

Constructors

OkfSpecValidator()
Creates the closed validator. It accepts no caller configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(OkfBundle bundle) OkfSpecValidation
Validates bundle without mutating it.

Operators

operator ==(Object other) bool
The equality operator.
inherited