OkfYamlEmitter class final

A small deterministic YAML emitter for values returned by package:yaml.

It intentionally does not try to preserve comments, anchors, aliases, quoting style, or whitespace. It emits ordinary mappings, sequences, and scalars in a canonical form that can be read by general YAML parsers.

Constructors

OkfYamlEmitter({List<String> preferredTopLevelKeys = okfPreferredFrontmatterKeyOrder})
Creates an emitter.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
preferredTopLevelKeys List<String>
Keys moved to the front of the root mapping, in this order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit(Map<String, Object?> frontmatter) String
Emits frontmatter without a trailing newline.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited