OkfBundleApplied class final

A conformant candidate that was committed.

Inheritance

Constructors

OkfBundleApplied({required OkfBundleCommitResult result})
Creates an applied result from the exact prepared commit.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
result OkfBundleCommitResult
The paths whose prepared bytes differed from the source bundle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited