OkfBundleLoadException class final

Thrown by OkfBundleLoader.load when inspection finds malformed files.

Implemented types

Constructors

OkfBundleLoadException(OkfBundleLoadResult result)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
result OkfBundleLoadResult
The partial bundle and all discovered failures.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited