validate method

OkfSpecValidation validate()

Validates the loaded bundle and merges load findings into one Report.

This is the complete Report for the bundle — the projection every adapter surfaces — in the canonical Report order.

Implementation

OkfSpecValidation validate() => validateCandidate(bundle);