load method

Future<OkfBundle> load(
  1. String rootPath
)

Loads a complete bundle.

Throws OkfBundleLoadException after scanning the entire tree when one or more Markdown concepts could not be decoded or parsed. Use inspect to consume the successfully loaded portion alongside those issues.

Implementation

Future<OkfBundle> load(String rootPath) async {
  final result = await inspect(rootPath);
  if (result.hasIssues) {
    throw OkfBundleLoadException(result);
  }
  return result.bundle;
}