OkfWriteRollbackException class final

A write failed and one or more compensating filesystem operations failed.

Implemented types

Constructors

OkfWriteRollbackException({required Object writeError, required Iterable<Object> rollbackErrors})
Creates a rollback failure that retains both the write and recovery errors.

Properties

hashCode int
The hash code for this object.
no setterinherited
rollbackErrors List<Object>
Errors encountered while restoring files and directories.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeError Object
The error that interrupted the original write.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited