OkfComputationContract class final
Typed view over an Attested Computation's top-level contract fields.
Constructors
-
OkfComputationContract({required String? runtime, required List<
OkfComputationParameter> parameters, required String? computation, required OkfExecutor? executor, required OkfAttester? attester}) -
const
Properties
- attester → OkfAttester?
-
Deterministic receipt checker.
final
- computation → String?
-
Optional path to a computation file.
final
- executor → OkfExecutor?
-
Instructions for running the computation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
→ List<
OkfComputationParameter> -
Typed holes whose values an agent may supply.
final
- runtime → String?
-
Runtime defining parameter binding and execution semantics.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited