OkfComputationParameter class final
One declared, runtime-specific computation parameter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Parameter name.
no setter
-
raw
→ Map<
String, Object?> -
The full mapping, including producer extensions.
final
- required → bool?
-
Whether the producer marked the parameter as required.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Runtime-specific parameter type.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
Object? value) → OkfComputationParameter? - Attempts to read a parameter mapping.