OkfUsageWindow class final
A date range framing one or more source usage counts.
Properties
- from → DateTime?
-
Inclusive beginning of the window, when parseable.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ Map<
String, Object?> -
The full mapping, including producer extensions.
final
- rawFrom → String?
-
The original scalar form of
from.no setter - rawTo → String?
-
The original scalar form of
to.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → DateTime?
-
Inclusive end of the window, when parseable.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
Object? value) → OkfUsageWindow? - Attempts to read a usage window from a YAML value.