OkfBundleApplicationRefused class final
A candidate refused because it contains a Spec error.
- Inheritance
-
- Object
- OkfBundleApplication
- OkfBundleApplicationRefused
Constructors
- OkfBundleApplicationRefused({required OkfSpecValidation validation})
-
Creates a refusal carrying the closed Spec judgment.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validation → OkfSpecValidation
-
The non-conformant candidate's Spec judgment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited