OkfBundleLoadIssue class final
A document that could not be decoded or parsed while loading a bundle.
Constructors
Properties
- code → String
-
A stable, machine-readable issue code.
final
- column → int?
-
One-based source column, when the parser supplied one.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int?
-
One-based source line, when the parser supplied one.
final
- message → String
-
A human-readable description of the issue.
final
- path → String
-
The POSIX-style path relative to the bundle root.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited